@@ -5,8 +5,8 @@ import matplotlib.pyplot as plt
 import networkx as nx
 from networkx.drawing.nx_pydot import graphviz_layout
 
+from fibonacci import fib
 from simple_visitor import SimpleVisitor
-from hw01.drawfunction.fibonacci import fib
 
 
 class GraphDescription:
